@@ -45,6 +45,30 @@ class TimecodeTester(unittest.TestCase):
         Timecode('60')
         Timecode('ms')
 
+        Timecode('23.98', 421729315)
+        Timecode('24', 421729315)
+        Timecode('25', 421729315)
+        Timecode('29.97', 421729315)
+        Timecode('30', 421729315)
+        Timecode('50', 421729315)
+        Timecode('59.94', 421729315)
+        Timecode('60', 421729315)
+        Timecode('ms', 421729315)
+
+        Timecode('24000/1000', '00:00:00:00')
+        Timecode('24000/1001', '00:00:00;00')
+        Timecode('30000/1000', '00:00:00:00')
+        Timecode('30000/1001', '00:00:00;00')
+        Timecode('60000/1000', '00:00:00:00')
+        Timecode('60000/1001', '00:00:00;00')
+
+        Timecode((24000, 1000), '00:00:00:00')
+        Timecode((24000, 1001), '00:00:00;00')
+        Timecode((30000, 1000), '00:00:00:00')
+        Timecode((30000, 1001), '00:00:00;00')
+        Timecode((60000, 1000), '00:00:00:00')
+        Timecode((60000, 1001), '00:00:00;00')
+
         Timecode(24, frames=12000)
         Timecode(23.98, '00:00:00:00')
         Timecode(24, '00:00:00:00')
@@ -157,6 +181,25 @@ class TimecodeTester(unittest.TestCase):
         tc = Timecode('59.94', frames=5178817)
         self.assertEqual('00:00:00;00', tc.__str__())
 
+        tc = Timecode('25', 421729315)
+        self.assertEqual('19:23:14:23', tc.__str__())
+
+        tc = Timecode('29.97', 421729315)
+        self.assertEqual('19:23:14;23', tc.__str__())
+        self.assertTrue(tc.drop_frame)
+
+    def test_start_seconds_argument_is_zero(self):
+        """testing if a ValueError will be raised when the start_seconds
+        parameters is zero.
+        """
+        with self.assertRaises(ValueError) as cm:
+            Timecode('29.97', start_seconds=0)
+
+        self.assertEqual(
+            str(cm.exception),
+            '``start_seconds`` argument can not be 0'
+        )
+
     def test_frame_to_tc(self):
         tc = Timecode('29.97', '00:00:00;01')
         self.assertEqual(0, tc.hrs)
@@ -313,81 +356,83 @@ class TimecodeTester(unittest.TestCase):
 
     def test_iteration(self):
         tc = Timecode('29.97', '03:36:09;23')
-        self.assertEqual("03:36:09;23", tc)
+        assert tc == "03:36:09;23"
+
         for x in range(60):
             t = tc.next()
             self.assertTrue(t)
-        self.assertEqual("03:36:11;23", t)
-        self.assertEqual(388764, tc.frames)
+
+        assert t == "03:36:11;23"
+        assert tc.frames == 388764
 
         tc = Timecode('29.97', '03:36:09;23')
         for x in range(60):
             t = tc.next()
             self.assertTrue(t)
-        self.assertEqual("03:36:11;23", t)
+        assert t == "03:36:11;23"
         self.assertEqual(388764, tc.frames)
 
         tc = Timecode('30', '03:36:09:23')
         for x in range(60):
             t = tc.next()
             self.assertTrue(t)
-        self.assertEqual("03:36:11:23", t)
+        assert t == "03:36:11:23"
         self.assertEqual(389154, tc.frames)
 
         tc = Timecode('25', '03:36:09:23')
         for x in range(60):
             t = tc.next()
             self.assertTrue(t)
-        self.assertEqual("03:36:12:08", t)
+        assert t == "03:36:12:08"
         self.assertEqual(324309, tc.frames)
 
         tc = Timecode('59.94', '03:36:09;23')
         for x in range(60):
             t = tc.next()
             self.assertTrue(t)
-        self.assertEqual("03:36:10;23", t)
+        assert t == "03:36:10;23"
         self.assertEqual(777444, tc.frames)
 
         tc = Timecode('60', '03:36:09:23')
         for x in range(60):
             t = tc.next()
             self.assertTrue(t)
-        self.assertEqual("03:36:10:23", t)
+        assert t == "03:36:10:23"
         self.assertEqual(778224, tc.frames)
 
         tc = Timecode('59.94', '03:36:09:23')
         for x in range(60):
             t = tc.next()
             self.assertTrue(t)
-        self.assertEqual("03:36:10:23", t)
+        assert t == "03:36:10:23"
         self.assertEqual(777444, tc.frames)
 
         tc = Timecode('23.98', '03:36:09:23')
         for x in range(60):
             t = tc.next()
             self.assertTrue(t)
-        self.assertEqual("03:36:12:11", t)
+        assert t == "03:36:12:11"
         self.assertEqual(311340, tc.frames)
 
         tc = Timecode('24', '03:36:09:23')
         for x in range(60):
             t = tc.next()
             self.assertTrue(t)
-        self.assertEqual("03:36:12:11", t)
+        assert t == "03:36:12:11"
         self.assertEqual(311340, tc.frames)
 
         tc = Timecode('ms', '03:36:09.230')
         for x in range(60):
             t = tc.next()
             self.assertIsNotNone(t)
-        self.assertEqual('03:36:09.290', t)
+        assert t == '03:36:09.290'
         self.assertEqual(12969291, tc.frames)
 
         tc = Timecode('24', frames=12000)
         for x in range(60):
             t = tc.next()
             self.assertTrue(t)
-        self.assertEqual("00:08:22:11", t)
+        assert t == "00:08:22:11"
         self.assertEqual(12060, tc.frames)
 
     def test_op_overloads_add(self):
@@ -470,7 +515,7 @@ class TimecodeTester(unittest.TestCase):
 
         tc = Timecode('23.98', '03:36:09:23')
         tc2 = Timecode('23.98', '00:00:29:23')
-        self.assertEqual(720, tc2)
+        self.assertEqual(720, tc2.frames)
         d = tc + tc2
         f = tc + 720
         self.assertEqual("03:36:39:23", d.__str__())
@@ -507,7 +552,7 @@ class TimecodeTester(unittest.TestCase):
         tc3 = tc1 + tc2
         self.assertEqual('29.97', tc3.framerate)
         self.assertEqual(12, tc3.frames)
-        self.assertEqual('00:00:00;11', tc3)
+        assert tc3 == '00:00:00;11'
 
     def test_frame_number_attribute_value_is_correctly_calculated(self):
         """testing if the Timecode.frame_number attribute is correctly
@@ -855,7 +900,7 @@ class TimecodeTester(unittest.TestCase):
         self.assertEqual('04:20:13;21', tc3.__str__())
 
     def test_framerate_can_be_changed(self):
-        """testing if the timecode value will be automaticall updated when the
+        """testing if the timecode value will be automatically updated when the
         framerate attribute is changed
         """
         tc1 = Timecode('25', frames=100)
@@ -866,6 +911,90 @@ class TimecodeTester(unittest.TestCase):
         self.assertEqual('00:00:08:03', tc1.__str__())
         self.assertEqual(100, tc1.frames)
 
+    def test_rational_framerate_conversions(self):
+        tc = Timecode('24000/1000', '00:00:00:00')
+        self.assertEqual(tc.framerate, '24')
+        self.assertEqual(tc._int_framerate, 24)
+
+        tc = Timecode('24000/1001', '00:00:00;00')
+        self.assertEqual(tc.framerate, '24')
+        self.assertEqual(tc._int_framerate, 24)
+
+        tc = Timecode('30000/1000', '00:00:00:00')
+        self.assertEqual(tc.framerate, '30')
+        self.assertEqual(tc._int_framerate, 30)
+
+        tc = Timecode('30000/1001', '00:00:00;00')
+        self.assertEqual(tc.framerate, '29.97')
+        self.assertEqual(tc._int_framerate, 30)
+
+        tc = Timecode('60000/1000', '00:00:00:00')
+        self.assertEqual(tc.framerate, '60')
+        self.assertEqual(tc._int_framerate, 60)
+
+        tc = Timecode('60000/1001', '00:00:00;00')
+        self.assertEqual(tc.framerate, '59.94')
+        self.assertEqual(tc._int_framerate, 60)
+
+        tc = Timecode((60000, 1001), '00:00:00;00')
+        self.assertEqual(tc.framerate, '59.94')
+        self.assertEqual(tc._int_framerate, 60)
+
+    def test_rational_frame_delimiter(self):
+        tc = Timecode('24000/1000', frames=1)
+        self.assertFalse(';' in tc.__repr__())
+
+        tc = Timecode('24000/1001', frames=1)
+        self.assertFalse(';' in tc.__repr__())
+
+        tc = Timecode('30000/1001', frames=1)
+        self.assertTrue(';' in tc.__repr__())
+
+    def test_ms_vs_fraction_frames(self):
+        tc1 = Timecode('ms', '00:00:00.040')
+        self.assertTrue(tc1.ms_frame)
+        self.assertFalse(tc1.fraction_frame)
+
+        tc2 = Timecode(24, '00:00:00.042')
+        self.assertTrue(tc2.fraction_frame)
+        self.assertFalse(tc2.ms_frame)
+
+        self.assertNotEqual(tc1, tc2)
+
+        self.assertEqual(tc1.frame_number, 40)
+        self.assertEqual(tc2.frame_number, 1)
+
+    def test_toggle_fractional_frame(self):
+        tc = Timecode(24, 421729315)
+        self.assertEqual(tc.__repr__(), '19:23:14:23')
+
+        tc.set_fractional(True)
+        self.assertEqual(tc.__repr__(), '19:23:14.958')
+
+        tc.set_fractional(False)
+        self.assertEqual(tc.__repr__(), '19:23:14:23')
+
+    def test_ge_overload(self):
+        tc1 = Timecode(24, '00:00:00:00')
+        tc2 = Timecode(24, '00:00:00:00')
+        tc3 = Timecode(24, '00:00:00:01')
+
+        self.assertTrue(tc1 == tc2)
+        self.assertTrue(tc1 >= tc2)
+        self.assertTrue(tc3 >= tc2)
+        self.assertFalse(tc2 >= tc3)
+
+    def test_le_overload(self):
+        tc1 = Timecode(24, '00:00:00:00')
+        tc2 = Timecode(24, '00:00:00:00')
+        tc3 = Timecode(24, '00:00:00:01')
+
+        self.assertTrue(tc1 == tc2)
+        self.assertTrue(tc1 <= tc2)
+        self.assertTrue(tc2 <= tc3)
+        self.assertFalse(tc2 >= tc3)
+
+
     # def test_exceptions(self):
     #     """test exceptions
     #     """
